@@ -30,6 +30,8 @@ interpret.gSlc <- function(gf){
    smooth.var <- c()
    linear.var <- c()
    num.basis <- c()   
+   
+   av <- rep("",0)
 
    if (nt)
       for (i in 1:nt) # work through all terms
@@ -46,11 +48,21 @@ interpret.gSlc <- function(gf){
         } else # paramatric 
 	  { if (kp>1) pf <- paste(pf,"+",terms[i],sep="") # add to parametric formula
           else pf <- paste(pf,terms[i],sep="")
-	    linear.var <- c(linear.var,terms[i])
+          av[kp] <- terms[i]
           kp <- kp + 1 # counts parametric terms
         } 
       }
+  
+  if (length(av)) {
+   
+        pred.formula <- as.formula(paste("~", paste(av,collapse = "+")))
+        pav <- all.vars(pred.formula)
+        pred.formula <- reformulate(pav)
 
+  } else {pred.formula <- ~1; pav <- rep("",0)}
+  
+  linear.var <- pav
+  
   var.list <- c(linear.var, smooth.var)
   ret<-list(smooth.spec=smooth.spec, svar =smooth.var, lvar=linear.var, varlist = var.list, response = response,nbas = num.basis)
   class(ret)<-"gamm.formula"
